@@ -71,6 +71,7 @@ class Work(ModelSQL, ModelView):
         depends=['type'],
         help='Estimated progress for this work')
     total_progress = fields.Function(fields.Float('Total Progress',
+            digits=(16, 4),
             help='Estimated total progress for this work and the sub-works',
             states={
                 'invisible': Eval('total_progress', None) == None,
@@ -125,9 +126,9 @@ class Work(ModelSQL, ModelView):
     def __register__(cls, module_name):
         TimesheetWork = Pool().get('timesheet.work')
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
-        table_project_work = TableHandler(cursor, cls, module_name)
-        table_timesheet_work = TableHandler(cursor, TimesheetWork, module_name)
+        cursor = Transaction().connection.cursor()
+        table_project_work = TableHandler(cls, module_name)
+        table_timesheet_work = TableHandler(TimesheetWork, module_name)
         project = cls.__table__()
         timesheet = TimesheetWork.__table__()
 
@@ -283,10 +284,6 @@ class Work(ModelSQL, ModelView):
     def on_change_with_company(self, name=None):
         return self.work.company.id if self.work else None
 
-    @classmethod
-    def search_comany(cls, name, clause):
-        return [('work.company',) + tuple(clause[1:])]
-
     @fields.depends('work')
     def on_change_with_timesheet_available(self, name=None):
         return self.work.timesheet_available if self.work else None
@@ -314,7 +311,7 @@ class Work(ModelSQL, ModelView):
 
     @classmethod
     def get_total(cls, works, names):
-        cursor = Transaction().cursor
+        cursor = Transaction().connection.cursor()
         table = cls.__table__()
 
         works = cls.search([
@@ -338,12 +335,14 @@ class Work(ModelSQL, ModelView):
             result[name] = cls.sum_tree(works, values, parents)
 
         if 'total_progress' in names:
+            digits = cls.total_progress.digits[1]
             total_progress = result['total_progress']
             total_effort = result['total_effort']
             for work in works:
                 if total_effort[work.id]:
-                    total_progress[work.id] /= (
-                        total_effort[work.id].total_seconds() / 60 / 60)
+                    total_progress[work.id] = round(total_progress[work.id] /
+                        (total_effort[work.id].total_seconds() / 60 / 60),
+                        digits)
                 else:
                     total_effort[work.id] = None
         return result
